<?php

// Exit if accessed directly
if ( !defined('ABSPATH') ) exit;

/**
 * Theme settings.
 * 
 * @package 	mantel
 * @author		Tokokoo
 * @license		license.txt
 * @since 		1.0
 *
 */

/**
 * Sets up the admin functionality.
 *
 * @since 1.0
 */
add_action( 'admin_menu', 'mantel_theme_admin_setup' );
function mantel_theme_admin_setup() {
    
	$prefix = hybrid_get_prefix();
	$settings_page = hybrid_get_settings_page_name();

	/* Create a settings meta box only on the theme settings page. */
	add_action( "load-{$settings_page}", 'mantel_theme_settings_meta_boxes' );

	/* Add a filter to validate/sanitize your settings. */
	add_filter( "sanitize_option_{$prefix}_theme_settings", 'mantel_theme_validate_settings' );
	
	/* Enqueue scripts */
	add_action( "admin_print_styles-$settings_page", 'mantel_admin_scripts' );
	
}

/**
 * Adds custom meta boxes to the theme settings page.
 *
 * @since 1.0
 */
function mantel_theme_settings_meta_boxes() {

	add_meta_box(
		'mantel-theme-meta-box-general',
		__( 'General settings', 'mantel' ),
		'mantel_theme_meta_box_general',
		'appearance_page_theme-settings',
		'normal',
		'high'
	);

	add_meta_box(
		'mantel-theme-meta-box-code',
		__( 'Custom Code settings', 'mantel' ),
		'mantel_theme_meta_box_code',
		'appearance_page_theme-settings',
		'normal',
		'high'
	);

	add_meta_box(
		'mantel-theme-meta-box-upgrade',
		__( 'Upgrade to Mantel Pro!', 'mantel' ),
		'mantel_theme_meta_box_upgrade',
		'appearance_page_theme-settings',
		'side',
		'high'
	);

}

/**
 * Render the meta boxes.
 *
 * @since 1.0
 */
function mantel_theme_meta_box_general() { ?>

	<table class="form-table">
	    
		<!-- Logo upload -->
		<tr class="logo">
			<th>
				<label for="<?php echo esc_attr( hybrid_settings_field_id( 'mantel_logo' ) ); ?>"><?php _e( 'Logo:', 'mantel' ); ?></label>
			</th>
			<td>
				<input type="text" id="<?php echo esc_attr( hybrid_settings_field_id( 'mantel_logo' ) ); ?>" name="<?php echo esc_attr( hybrid_settings_field_name( 'mantel_logo' ) ); ?>" value="<?php echo esc_url( hybrid_get_setting( 'mantel_logo' ) ); ?>" />
				<input id="mantel_logo_upload_button" class="button" type="button" value="<?php esc_attr_e( 'Upload', 'mantel' ) ?>" />
				<br />
				<span class="description"><?php esc_html_e( 'Upload a logo for your website, or specify the image address of your online logo.', 'mantel' ); ?></span>
				
				<?php
				if ( hybrid_get_setting( 'mantel_logo' ) ) { ?>
                    <p><img src="<?php echo esc_url( hybrid_get_setting( 'mantel_logo' ) ); ?>" /></p>
				<?php } ?>
			</td>
		</tr>	

		<!-- Favicon upload -->
		<tr class="favicon">
			<th>
				<label for="<?php echo esc_attr( hybrid_settings_field_id( 'mantel_favicon' ) ); ?>"><?php _e( 'Favicon:', 'mantel' ); ?></label>
			</th>
			<td>
				<input type="text" id="<?php echo esc_attr( hybrid_settings_field_id( 'mantel_favicon' ) ); ?>" name="<?php echo esc_attr( hybrid_settings_field_name( 'mantel_favicon' ) ); ?>" value="<?php echo esc_url( hybrid_get_setting( 'mantel_favicon' ) ); ?>" />
				<input id="mantel_favicon_upload_button" class="button" type="button" value="<?php esc_attr_e( 'Upload', 'mantel' ) ?>" />
				<br />
				<span class="description"><?php esc_html_e( 'Upload a favicon for your website, or specify the image address of your online favicon.', 'mantel' ); ?></span>
				
				<?php
				if ( hybrid_get_setting( 'mantel_favicon' ) ) { ?>
                    <p><img src="<?php echo esc_url( hybrid_get_setting( 'mantel_favicon' ) ); ?>" /></p>
				<?php } ?>
			</td>
		</tr>

		<!-- Layouts -->
		<tr>
			<th>
				<label><?php _e( 'Global layout settings:', 'mantel' ); ?></label>
			</th>
			<td>
				<span class="description">
					<?php printf( __( 'You can setup the global layout on the <a href="%s">Customize</a> page.', 'mantel' ), esc_url( admin_url( 'customize.php' ) ) ); ?>
				</span>
			</td>
		</tr>

		<!-- End custom form elements. -->
	</table><!-- .form-table -->

	<?php
	
}

/**
 * Render the meta boxes.
 *
 * @since 1.0
 */
function mantel_theme_meta_box_code() { ?>

	<table class="form-table">

		<!-- Custom CSS -->
		<tr>
			<th>
				<label for="<?php echo esc_attr( hybrid_settings_field_id( 'mantel_custom_css' ) ); ?>"><?php _e( 'Custom CSS:', 'mantel' ); ?></label>
			</th>
			<td>
				<textarea id="<?php echo esc_attr( hybrid_settings_field_id( 'mantel_custom_css' ) ); ?>" name="<?php echo esc_attr( hybrid_settings_field_name( 'mantel_custom_css' ) ); ?>" cols="60" rows="8"><?php echo wp_htmledit_pre( esc_html( hybrid_get_setting( 'mantel_custom_css' ) ) ); ?></textarea>
				<span class="description"><?php esc_html_e( 'Quickly add some CSS code to your theme.', 'mantel' ); ?></span>
			</td>
		</tr>

		<!-- Header Code -->
		<tr>
			<th>
				<label for="<?php echo esc_attr( hybrid_settings_field_id( 'mantel_header_code' ) ); ?>"><?php _e( 'Header Code:', 'mantel' ); ?></label>
			</th>
			<td>
				<textarea id="<?php echo esc_attr( hybrid_settings_field_id( 'mantel_header_code' ) ); ?>" name="<?php echo esc_attr( hybrid_settings_field_name( 'mantel_header_code' ) ); ?>" cols="60" rows="8"><?php echo esc_html( hybrid_get_setting( 'mantel_header_code' ) ); ?></textarea>
				<span class="description"><?php esc_html_e( 'Add any custom scripts or styles like the meta verification from various search engine, google fonts, etc. It will be inserted before the closing head tag of the theme.', 'mantel' ); ?></span>
			</td>
		</tr>

		<!-- Header Code -->
		<tr>
			<th>
				<label for="<?php echo esc_attr( hybrid_settings_field_id( 'mantel_footer_code' ) ); ?>"><?php _e( 'Footer Code:', 'mantel' ); ?></label>
			</th>
			<td>
				<textarea id="<?php echo esc_attr( hybrid_settings_field_id( 'mantel_footer_code' ) ); ?>" name="<?php echo esc_attr( hybrid_settings_field_name( 'mantel_footer_code' ) ); ?>" cols="60" rows="8"><?php echo esc_html( hybrid_get_setting( 'mantel_footer_code' ) ); ?></textarea>
				<span class="description"><?php esc_html_e( 'Add analytic code or add any custom scripts here. It will be inserted before the closing body tag of the theme.', 'mantel' ); ?></span>
			</td>
		</tr>

		<!-- End custom form elements. -->
	</table><!-- .form-table -->

	<?php
	
}

/**
 * Render the meta boxes.
 *
 * @since 1.0
 */
function mantel_theme_meta_box_upgrade() { ?>

	<table class="form-table">
		<tr>
			<td>
				<?php _e( '<p>You are using the lite version of Mantel Theme. Upgrade to Pro for extra features.</p>
				<a class="button button-primary button-hero" href="' . esc_url( admin_url( 'themes.php?page=mantel-premium-upgrade' ) ) . '">' . __( 'Find out more', 'mantel' ). '</a>
				', 'mantel' ); ?>
			</td>
		</tr>
	</table><!-- .form-table -->

	<?php

}

/**
 * Validate theme settings.
 *
 * @since 1.0
 */
function mantel_theme_validate_settings( $input ) {
    
	$input['mantel_logo'] = esc_url_raw( $input['mantel_logo'] ); 
	$input['mantel_favicon'] = esc_url_raw( $input['mantel_favicon'] );
    $input['mantel_custom_css'] = wp_filter_nohtml_kses( $input['mantel_custom_css'] );
    $input['mantel_header_code'] = stripslashes( $input['mantel_header_code'] );
    $input['mantel_footer_code'] = stripslashes( $input['mantel_footer_code'] );

    /* Return the array of theme settings. */
    return $input;
}

/**
 * Enqueue scripts.
 *
 * @since 1.0
 */
function mantel_admin_scripts( $hook_suffix ) {
	    
	/* Enqueue Scripts */
	wp_enqueue_script( 'mantel-theme-settings-script', trailingslashit ( THEME_URI ) . 'admin/functions-admin.js', array( 'jquery', 'media-upload', 'thickbox' ), '1.0', false );

	/* Localize script strings */
	wp_localize_script( 'mantel-theme-settings-script', 'js_text', array( 'insert_into_post' => __( 'Use this Image', 'mantel' ) ) );

	/* Enqueue Styles */
	wp_enqueue_style( 'mantel-theme-settings-style', trailingslashit ( THEME_URI ) . 'admin/functions-admin.css', false, 1.0, 'screen' );

}

?>