<?php

// Exit if accessed directly
if ( !defined('ABSPATH') ) exit;

/**
 * Theme-additional functions
 *
 * @package 	mantel
 * @author		Tokokoo
 * @license		license.txt
 * @since 		1.0
 *
 */

/**
 * Redirect to the theme settings page after user activated the theme.
 * 
 * @since 1.0
 */
global $pagenow;
if ( is_admin() && isset( $_GET['activated'] ) && $pagenow == 'themes.php' ) {

	wp_redirect( admin_url( 'themes.php?page=theme-settings' ) );
	exit;
	
}

/**
 * Site Title/Logo
 * 
 * @since 1.0
 */
if ( ! function_exists( 'mantel_site_title' ) ) :

function mantel_site_title() {

	$logo = hybrid_get_setting( 'mantel_logo' );

	if ($logo) echo '<div class="has-logo">' . "\n";

	echo '<div class="site-branding">';

	echo '<div class="site-logo">' . "\n";

		echo '<a href="' . esc_url( get_home_url() ) . '" title="' . esc_attr( get_bloginfo( 'name' ) ) . '" rel="home">';

			if( $logo ) echo '<img src="' . esc_url( $logo ) . '" alt="' . esc_attr( get_bloginfo( 'name' ) ) . '">';

		echo '</a>' . "\n";

	echo '</div><!-- .site-logo -->';

?>

	<hgroup>
		<?php hybrid_site_title(); ?>
		<?php hybrid_site_description(); ?>
	</hgroup>

	</div><!-- .site-branding -->

<?php 
	if ($logo) echo '</div><!-- .has-logo -->';
}

endif;

/**
 * Author Box on single post.
 * 
 * @since 1.0
 */
if ( ! function_exists( 'mantel_author_box' ) ):

function mantel_author_box() {

	if ( get_the_author_meta( 'description' ) ) { ?>

		<aside class="post-author">
			<h4 class="title"><?php _e( 'About the author', 'mantel' ); ?></h4>
			<div class="author-box">
				<?php echo get_avatar( get_the_author_meta( 'user_email' ), apply_filters( 'mantel_author_bio_avatar_size', 80 ) ); ?>
				<div class="author-desc">
					<a class="author-name" href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>" rel="author"><?php echo esc_attr( get_the_author() ); ?></a> 
					<p><?php echo esc_textarea( get_the_author_meta( 'description' ) ); ?></p>
				</div>
			</div>
		</aside>

	<?php }

}

endif;

/**
 * Favicon
 *
 * @since 1.0
 */
add_action( 'wp_head', 'mantel_custom_favicon', 5 );
function mantel_custom_favicon() {

	$fav = hybrid_get_setting( 'mantel_favicon' );
	if ( $fav )
		echo '<link rel="shortcut icon" href="'. esc_url( $fav ) .'">'."\n";

}

/**
 * Custom CSS output
 *
 * @since 1.0
 */
add_action( 'wp_head', 'mantel_custom_css_output', 10 );
function mantel_custom_css_output() {

	$custom_css = hybrid_get_setting( 'mantel_custom_css' );
	if ( $custom_css != '' ) {
		echo "<!-- Custom Style -->\n<style type=\"text/css\">\n" . esc_html( $custom_css ) . "\n</style>\n";
	}

	$custom_logo_background = get_theme_mod( 'mantel_logo_background' );
	if ( $custom_logo_background ) {
		echo "<!-- Custom Style -->\n<style type=\"text/css\">\n .site-logo{background:" . esc_html( $custom_logo_background ) . "}\n</style>\n";
	}
}

/**
 * Header Code
 *
 * @since 1.0
 */
add_action( 'wp_head', 'mantel_header_code' );
function mantel_header_code(){

	$hcode = hybrid_get_setting( 'mantel_header_code' );
	if ( $hcode ) 
		echo "\n" . stripslashes( $hcode ) . "\n";

}

/**
 * Footer Code
 *
 * @since 1.0
 */
add_action( 'wp_footer', 'mantel_footer_code' );
function mantel_footer_code(){

	$fcode = hybrid_get_setting( 'mantel_footer_code' );
	if ( $fcode ) 
		echo "\n" . stripslashes( $fcode ) . "\n";

}

/**
 * Show full-sized image on attachment page
 *
 * @since 1.1
 */
add_filter('prepend_attachment', 'mantel_attachment_change_size');
function mantel_attachment_change_size($p) {
    return '<p class="attachment">'.wp_get_attachment_link(get_the_ID(), 'full', false).'</p>';
}

/**
 * Add customizer control for logo background
 *
 * @since 1.1
 */
add_action('customize_register', 'mantel_customize');
function mantel_customize($wp_customize) {
	$wp_customize->add_setting( 'mantel_logo_background', array(
        'default'        => '#b089b7',
    ) );
 
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'mantel_logo_background', array(
        'label'   => __( 'Logo Background Color', 'mantel' ),
        'section' => 'colors',
        'settings'   => 'mantel_logo_background',
    ) ) );

    $wp_customize->get_setting('mantel_logo_background')->transport = 'postMessage';

    if ( $wp_customize->is_preview() && ! is_admin() )
	    add_action( 'wp_footer', 'mantel_customize_preview', 21);
}

/**
 * Add live preview for theme customizer
 *
 * @since 1.1
 */
function mantel_customize_preview() {
    ?>
    <script type="text/javascript">
    ( function( $ ){
    wp.customize( 'mantel_logo_background', function( value ) {
        value.bind( function( to ) {
            $('.site-logo').css('background', to ? to : '' );
        });
    });
    } )( jQuery )
    </script>
    <?php
}

?>