<?php

// Exit if accessed directly
if ( !defined('ABSPATH')) exit;

/**
 * Custom social network widget
 * 
 * @package 	mantel
 * @author		Tokokoo
 * @license		license.txt
 * @since 		1.0
 *
 */
class mantel_social extends WP_Widget {

	/**
	 * Widget setup
	 */
	function mantel_social() {

		$widget_ops = array( 
			'classname' => 'mantel_social_widget', 
			'description' => __( 'A custom widget to display the social network icons.', 'mantel' ) 
		);

		$control_ops = array( 
			'width' => 350, 
			'height' => 350, 
			'id_base' => 'mantel_social_widget' 
		);

		$this->WP_Widget( 'mantel_social_widget', __( '&raquo; Tokokoo Social Connect', 'mantel' ), $widget_ops, $control_ops );
	}

	/**
	 * Display widget
	 */
	function widget( $args, $instance ) {
		extract( $args, EXTR_SKIP );
 
		$title = apply_filters( 'widget_title', $instance['title'] );
		$rss = esc_url( $instance['rss'] );
		$email_id = is_email( $instance['email_id'] );
		$twitter_id = esc_attr( $instance['twitter_id'] );
		$fb_id = esc_attr( $instance['fb_id'] );
		$gplus_id = esc_attr( $instance['gplus_id'] );
		$ytube_id = esc_attr( $instance['ytube_id'] );
		$flickr_id = esc_attr( $instance['flickr_id'] );
		$linkedin_id = esc_attr( $instance['linkedin_id'] );
		$pinterest_id = esc_attr( $instance['pinterest_id'] );
		$dribbble_id = esc_attr( $instance['dribbble_id'] );
		$github_id = esc_attr( $instance['github_id'] );
		$lastfm_id = esc_attr( $instance['lastfm_id'] );
		$vimeo_id = esc_attr( $instance['vimeo_id'] );
		$tumblr_id = esc_attr( $instance['tumblr_id'] );
		$instagram_id = esc_attr( $instance['instagram_id'] );
		
		echo $before_widget;
 
		if (!empty( $title ))
			echo $before_title . $title . $after_title;

		$output = get_transient( 'socialwidget_' . $widget_id );
		
		if ( $output === false ) {

			$output = '<ul class="social-buttons clearfix">';

				if ( $rss ) {
					$output .= '<li><a class="rssfeed" href="' . $rss . '" target="_blank">' . __( 'Rss Feed', 'mantel' ) . '</a></li>';
				} if ( $email_id ) {
					$output .= '<li><a class="email" href="mailto:' . $email_id . '" target="_blank">' . __( 'Email', 'mantel' ) . '</a></li>';
				} if ( $twitter_id ) {
					$output .= '<li><a class="twitter" href="http://twitter.com/' . $twitter_id . '" target="_blank">' . __( 'Twitter', 'mantel' ) . '</a></li>';
				} if ( $fb_id ) {
					$output .= '<li><a class="fb" href="http://www.facebook.com/' . $fb_id . '" target="_blank">' . __( 'Facebook', 'mantel' ) . '</a></li>';
				} if ( $gplus_id ) {
					$output .= '<li><a class="gplus" href="https://plus.google.com/u/' . $gplus_id . '" target="_blank">' . __( 'Google Plus', 'mantel' ) . '</a></li>';
				} if ( $ytube_id ) {
					$output .= '<li><a class="ytube" href="http://www.youtube.com/user/' . $ytube_id . '" target="_blank">' . __( 'Youtube', 'mantel' ) . '</a></li>';
				} if ( $flickr_id ) {
					$output .= '<li><a class="flickr" href="http://www.flickr.com/photos/' . $flickr_id . '" target="_blank">' . __( 'Flickr', 'mantel' ) . '</a></li>';
				} if ( $linkedin_id ) {
					$output .= '<li><a class="linkedin" href="http://linkedin.com/in/' . $linkedin_id . '" target="_blank">' . __( 'Linkedin', 'mantel' ) . '</a></li>';
				} if ( $pinterest_id ) {
					$output .= '<li><a class="pinterest" href="http://pinterest.com/' . $pinterest_id . '" target="_blank">' . __( 'Pinterest', 'mantel' ) . '</a></li>';
				} if ( $dribbble_id ) {
					$output .= '<li><a class="dribbble" href="http://dribbble.com/' . $dribbble_id . '" target="_blank">' . __( 'Dribbble', 'mantel' ) . '</a></li>';
				} if ( $github_id ) {
					$output .= '<li><a class="github" href="https://github.com/' . $github_id . '" target="_blank">' . __( 'Github', 'mantel' ) . '</a></li>';
				} if ( $lastfm_id ) {
					$output .= '<li><a class="lastfm" href="http://www.last.fm/user/' . $lastfm_id . '" target="_blank">' . __( 'Last FM', 'mantel' ) . '</a></li>';
				} if ( $vimeo_id ) {
					$output .= '<li><a class="vimeo" href="http://vimeo.com/' . $vimeo_id . '" target="_blank">' . __( 'Vimeo', 'mantel' ) . '</a></li>';
				} if ( $tumblr_id ) {
					$output .= '<li><a class="tumblr" href="http://' . $tumblr_id . '.tumblr.com" target="_blank">' . __( 'Tumblr', 'mantel' ) . '</a></li>';
				} if ( $instagram_id ) {
					$output .= '<li><a class="instagram" href="http://instagram.com/' . $instagram_id . '" target="_blank">' . __( 'Instagram', 'mantel' ) . '</a></li>';
				}

			$output .= '</ul>';

			set_transient( 'socialwidget_' . $widget_id, $output, 60*60*12 );
		
		}

			echo $output;

		echo $after_widget;

	}
 	
	/**
	 * Update widget
	 */
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = esc_attr( $new_instance['title'] );
		$instance['rss'] = esc_url( $new_instance['rss'] );
		$instance['email_id'] = is_email( $new_instance['email_id'] );
		$instance['twitter_id'] = esc_attr( $new_instance['twitter_id'] );
		$instance['fb_id'] = esc_attr( $new_instance['fb_id'] );
		$instance['gplus_id'] = esc_attr( $new_instance['gplus_id'] );
		$instance['ytube_id'] = esc_attr( $new_instance['ytube_id'] );
		$instance['flickr_id'] = esc_attr( $new_instance['flickr_id'] );
		$instance['linkedin_id'] = esc_attr( $new_instance['linkedin_id'] );
		$instance['pinterest_id'] = esc_attr( $new_instance['pinterest_id'] );
		$instance['dribbble_id'] = esc_attr( $new_instance['dribbble_id'] );
		$instance['github_id'] = esc_attr( $new_instance['github_id'] );
		$instance['lastfm_id'] = esc_attr( $new_instance['lastfm_id'] );
		$instance['vimeo_id'] = esc_attr( $new_instance['vimeo_id'] );
		$instance['tumblr_id'] = esc_attr( $new_instance['tumblr_id'] );
		$instance['instagram_id'] = esc_attr( $new_instance['instagram_id'] );

		delete_transient( 'socialwidget_' . $this->id );

		return $instance;
	}

	/**
	 * Widget setting
	 */
	function form( $instance ) {

		/* Set up some default widget settings. */
        $defaults = array(
            'title' => '',
            'rss' => '',
            'email_id' => '',
            'twitter_id' => '',
            'fb_id' => '',
            'gplus_id' => '',
            'ytube_id' => '',
            'flickr_id' => '',
            'linkedin_id' => '',
            'pinterest_id' => '',
            'dribbble_id' => '',
            'github_id' => '',
            'lastfm_id' => '',
            'vimeo_id' => '',
            'tumblr_id' => '',
            'instagram_id' => ''
        );
        $instance = wp_parse_args( (array) $instance, $defaults );
		$title = esc_attr( $instance['title'] );
		$rss = esc_url( $instance['rss'] );
		$email_id = is_email( $instance['email_id'] );
		$twitter_id = esc_attr( $instance['twitter_id'] );
		$fb_id = esc_attr( $instance['fb_id'] );
		$gplus_id = esc_attr( $instance['gplus_id'] );
		$ytube_id = esc_attr( $instance['ytube_id'] );
		$flickr_id = esc_attr( $instance['flickr_id'] );
		$linkedin_id = esc_attr( $instance['linkedin_id'] );
		$pinterest_id = esc_attr( $instance['pinterest_id'] );
		$dribbble_id = esc_attr( $instance['dribbble_id'] );
		$github_id = esc_attr( $instance['github_id'] );
		$lastfm_id = esc_attr( $instance['lastfm_id'] );
		$vimeo_id = esc_attr( $instance['vimeo_id'] );
		$tumblr_id = esc_attr( $instance['tumblr_id'] );
		$instagram_id = esc_attr( $instance['instagram_id'] );

	?>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php _e( 'Title:', 'mantel' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo $title; ?>" />
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'rss' ) ); ?>"><?php _e( 'Rss URL:', 'mantel' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'rss' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'rss' ) ); ?>" type="text" value="<?php echo $rss; ?>" />
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'email_id' ) ); ?>"><?php _e( 'Email:', 'mantel' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'email_id' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'email_id' ) ); ?>" type="text" value="<?php echo $email_id; ?>" />
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'twitter_id' ) ); ?>"><?php _e( 'Twitter Username:', 'mantel' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'twitter_id' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'twitter_id' ) ); ?>" type="text" value="<?php echo $twitter_id; ?>" />
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'fb_id' ) ); ?>"><?php _e( 'Facebook Username:', 'mantel' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'fb_id' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'fb_id' ) ); ?>" type="text" value="<?php echo $fb_id; ?>" />
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'gplus_id' ) ); ?>"><?php _e( 'Google Plus Username:', 'mantel' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'gplus_id' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'gplus_id' ) ); ?>" type="text" value="<?php echo $gplus_id; ?>" />
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'ytube_id' ) ); ?>"><?php _e( 'Youtube Username:', 'mantel' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'ytube_id' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'ytube_id' ) ); ?>" type="text" value="<?php echo $ytube_id; ?>" />
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'flickr_id' ) ); ?>"><?php _e( 'Flickr Username:', 'mantel' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'flickr_id' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'flickr_id' ) ); ?>" type="text" value="<?php echo $flickr_id; ?>" />
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'linkedin_id' ) ); ?>"><?php _e( 'Linkedin Username:', 'mantel' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'linkedin_id' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'linkedin_id' ) ); ?>" type="text" value="<?php echo $linkedin_id; ?>" />
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'pinterest_id' ) ); ?>"><?php _e( 'Pinterest Username:', 'mantel' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'pinterest_id' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'pinterest_id' ) ); ?>" type="text" value="<?php echo $pinterest_id; ?>" />
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'dribbble_id' ) ); ?>"><?php _e( 'Dribbble Username:', 'mantel' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'dribbble_id' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'dribbble_id' ) ); ?>" type="text" value="<?php echo $dribbble_id; ?>" />
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'github_id' ) ); ?>"><?php _e( 'Github Username:', 'mantel' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'github_id' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'github_id' ) ); ?>" type="text" value="<?php echo $github_id; ?>" />
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'lastfm_id' ) ); ?>"><?php _e( 'Last FM Username:', 'mantel' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'lastfm_id' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'lastfm_id' ) ); ?>" type="text" value="<?php echo $lastfm_id; ?>" />
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'vimeo_id' ) ); ?>"><?php _e( 'Vimeo Username:', 'mantel' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'vimeo_id' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'vimeo_id' ) ); ?>" type="text" value="<?php echo $vimeo_id; ?>" />
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'tumblr_id' ) ); ?>"><?php _e( 'Tumblr Username:', 'mantel' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'tumblr_id' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'tumblr_id' ) ); ?>" type="text" value="<?php echo $tumblr_id; ?>" />
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'instagram_id' ) ); ?>"><?php _e( 'Instagram Username:', 'mantel' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'instagram_id' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'instagram_id' ) ); ?>" type="text" value="<?php echo $instagram_id; ?>" />
		</p>

	<?php
	}
 
}
?>